<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>Fm::FontButton</name>
    <message>
        <location filename="../../fontbutton.cpp" line="46"/>
        <source>Bold</source>
        <translation>Tučné</translation>
    </message>
    <message>
        <location filename="../../fontbutton.cpp" line="50"/>
        <source>Italic</source>
        <translation>Kurzíva</translation>
    </message>
</context>
<context>
    <name>MainDialog</name>
    <message>
        <location filename="../../ui_obconf.h" line="1012"/>
        <source>Window Manager Preferences</source>
        <translation>Nastavení správce oken</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1017"/>
        <source>Theme</source>
        <translation>Motiv</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1019"/>
        <source>Appearance</source>
        <translation>Vzhled</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1021"/>
        <source>Font</source>
        <translation>Písmo</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1023"/>
        <location filename="../../ui_obconf.h" line="1038"/>
        <source>Windows</source>
        <translation>Okna</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1025"/>
        <source>Move &amp; Resize</source>
        <translation>Přesunutí a změna velikosti</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1027"/>
        <source>Mouse</source>
        <translation>Myš</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1029"/>
        <source>Desktops</source>
        <translation>Pracovní plochy</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1031"/>
        <source>Margins</source>
        <translation>Okraje</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1033"/>
        <source>Dock</source>
        <translation>Panel</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1036"/>
        <source>&amp;Install a new theme...</source>
        <translation>&amp;Nainstalovat nový motiv...</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1037"/>
        <source>Create a theme &amp;archive (.obt)...</source>
        <translation>Vytvořit &amp;archiv s motivem (.obt)...</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1039"/>
        <source>&amp;Windows retain a border when undecorated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1040"/>
        <source>A&amp;nimate iconify and restore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1041"/>
        <source>Window Titles</source>
        <translation>Názvy oken</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1042"/>
        <source>Button order:</source>
        <translation>Pořadí tlačítek:</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1043"/>
        <source>N: Window icon
L: Window label (Title)
I: Iconify (Minimize)
M: Maximize
C: Close
S: Shade (Roll up)
D: Omnipresent (On all desktops)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1056"/>
        <source>&amp;Active window title: </source>
        <translation>Název činné&amp;ho okna:</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1057"/>
        <source>&amp;Inactive window title: </source>
        <translation>Název &amp;nečinného okna:</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1058"/>
        <source>Menu &amp;header: </source>
        <translation>&amp;Nadpis nabídky:</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1059"/>
        <source>&amp;Menu Item: </source>
        <translation>Položka na&amp;bídky:</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1060"/>
        <source>Active &amp;On-screen display: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1061"/>
        <source>Inactive O&amp;n-screen display: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1062"/>
        <source>Focus &amp;new windows when they appear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1063"/>
        <source>&amp;Place new windows under the mouse pointer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1064"/>
        <source>&amp;Center new windows when they are placed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1065"/>
        <source>Prefer to place new windows &amp;on:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1068"/>
        <source>All monitors</source>
        <translation>Všechny obrazovky</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1069"/>
        <source>The active monitor</source>
        <translation>Činná obrazovka</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1070"/>
        <source>The monitor with the mouse</source>
        <translation>Obrazovka s myší</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1071"/>
        <source>Primary monitor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1073"/>
        <source>Primary Monitor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1074"/>
        <source>The primary monitor is where Openbox will place dialogs, such as the one used for cycling windows.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1075"/>
        <source>Primary &amp;monitor:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1078"/>
        <source>Fixed Monitor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1079"/>
        <source>Active Monitor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1080"/>
        <source>Monitor With Mouse Pointer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1082"/>
        <source>&amp;Fixed monitor:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1083"/>
        <source>Moving and Resizing Windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1084"/>
        <source>Update the window contents while &amp;resizing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1085"/>
        <source>Drag &amp;threshold distance:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1086"/>
        <source>Amount of resistance against other &amp;windows:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1087"/>
        <source>Amount of resistance against screen &amp;edges:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1088"/>
        <source>&amp;Amount of time to wait before switching:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1089"/>
        <source>&amp;Switch desktops when moving a window past the screen edge</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1090"/>
        <source>Information Dialog</source>
        <translation>Dialog s informacemi</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1093"/>
        <location filename="../../ui_obconf.h" line="1100"/>
        <source>Centered</source>
        <translation>Vystředěno</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1094"/>
        <source>From left edge</source>
        <translation>Od levého okraje</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1095"/>
        <source>From right edge</source>
        <translation>Od pravého okraje</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1097"/>
        <source>Fixed &amp;y position:</source>
        <translation>Pevná poloha &amp;y:</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1101"/>
        <source>From top edge</source>
        <translation>Od horního okraje</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1102"/>
        <source>From bottom edge</source>
        <translation>Od spodního okraje</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1104"/>
        <source>Information dialog&apos;s &amp;position:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1105"/>
        <source>Fixed &amp;x position:</source>
        <translation>Pevná poloha &amp;x:</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1106"/>
        <source>Show &amp;information dialog:</source>
        <translation>Ukázat dialog s &amp;informacemi:</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1109"/>
        <source>When resizing terminal windows</source>
        <translation>Při změně velikosti oken terminálu</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1110"/>
        <source>Always</source>
        <translation>Vždy</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1111"/>
        <source>Never</source>
        <translation>Nikdy</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1115"/>
        <source>Centered on the window</source>
        <translation>Uprostřed okna</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1116"/>
        <source>Above the window</source>
        <translation>Nad oknem</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1117"/>
        <source>Fixed position on screen</source>
        <translation>Pevná poloha na obrazovce</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1119"/>
        <source>Focusing Windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1120"/>
        <source>Focus windows when the mouse pointer moves over them</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1121"/>
        <source>&amp;Delay before focusing and raising windows:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1122"/>
        <source>Move focus under the mouse when &amp;switching desktops</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1123"/>
        <source>Move focus &amp;under the mouse when the mouse is not moving</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1124"/>
        <source>&amp;Raise windows when the mouse pointer moves over them</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1125"/>
        <source>Titlebar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1126"/>
        <source>Double click on the &amp;titlebar:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1129"/>
        <source>Maximizes the window</source>
        <translation>Zvětší okno</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1130"/>
        <source>Shades the window</source>
        <translation>Sroluje okno</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1132"/>
        <source>Double click ti&amp;me:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1133"/>
        <source>&amp;Show a notification when switching desktops</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1134"/>
        <source>&amp;Amount of time to show the notification for:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1135"/>
        <source>&amp;Number of desktops: </source>
        <translation>P&amp;očet pracovních ploch:</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1136"/>
        <source>&amp;Desktop names:</source>
        <translation>Názvy &amp;pracovní plochy:</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1137"/>
        <source>Desktop Margins</source>
        <translation>Okraje pracovní plochy</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1138"/>
        <source>Desktop margins are reserved areas on the edge of your screen.  New windows will not be placed within a margin, and maximized windows will not cover them.</source>
        <translation>Okraje plochy je možné vyhradit pro jiné účely. Nová okna nebudou zasahovat do okrajů a zvětšená okna je nebudou krýt.</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1139"/>
        <source>Left:</source>
        <translation>Vlevo:</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1140"/>
        <location filename="../../ui_obconf.h" line="1142"/>
        <location filename="../../ui_obconf.h" line="1144"/>
        <location filename="../../ui_obconf.h" line="1146"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1141"/>
        <source>Top:</source>
        <translation>Nahoře:</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1143"/>
        <source>Right:</source>
        <translation>Vpravo:</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1145"/>
        <source>Bottom:</source>
        <translation>Dole:</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1147"/>
        <source>The dock is a special container for &quot;dockapps&quot;, or dock applications.  It is not visible on screen until a dockapp is run.  Dockapps can be used to show things like a clock, or to provide you with a system tray.</source>
        <translation>Panel je zvláštní oblast, do které se mohou umisťovat dokovací aplikace. Není viditelná, dokud není nespustíte nějakou dokovací aplikaci. Dokovací aplikace mohou být použity pro zobrazování věcí jako hodiny nebo systémová oblast.</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1148"/>
        <source>Position</source>
        <translation>Poloha</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1149"/>
        <source>&amp;Position:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1152"/>
        <source>Top Left</source>
        <translation>Vlevo nahoře</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1153"/>
        <source>Top</source>
        <translation>Nahoře</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1154"/>
        <source>Top Right</source>
        <translation>Vpravo nahoře</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1155"/>
        <source>Left</source>
        <translation>Vlevo</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1156"/>
        <source>Right</source>
        <translation>Vpravo</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1157"/>
        <source>Bottom Left</source>
        <translation>Vlevo dole</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1158"/>
        <source>Bottom</source>
        <translation>Dole</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1159"/>
        <source>Bottom Right</source>
        <translation>Vpravo dole</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1160"/>
        <source>Floating</source>
        <translation>Plovoucí</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1162"/>
        <source>&amp;Floating position:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1163"/>
        <source>x</source>
        <translation>x</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1164"/>
        <source>Allow &amp;windows to be placed within the dock&apos;s area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1165"/>
        <source>&amp;Orientation: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1168"/>
        <source>Vertical</source>
        <translation>Svisle</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1169"/>
        <source>Horizontal</source>
        <translation>Vodorovně</translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1171"/>
        <source>Stacking</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1172"/>
        <source>Keep dock &amp;above other windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1173"/>
        <source>A&amp;llow dock to be both above and below windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1174"/>
        <source>Keep dock &amp;below other windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1175"/>
        <source>Hiding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1176"/>
        <source>&amp;Delay before hiding:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1177"/>
        <source>Delay before &amp;showing:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1178"/>
        <source>&amp;Hide off screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../ui_obconf.h" line="1179"/>
        <source>About</source>
        <translation>O programu</translation>
    </message>
</context>
<context>
    <name>Obconf::MainDialog</name>
    <message>
        <location filename="../../theme.cpp" line="150"/>
        <location filename="../../theme.cpp" line="160"/>
        <source>Choose an Openbox theme</source>
        <translation>Vyberte motiv Openboxu</translation>
    </message>
    <message>
        <location filename="../../desktops.cpp" line="65"/>
        <location filename="../../desktops.cpp" line="87"/>
        <location filename="../../desktops.cpp" line="99"/>
        <source>(Unnamed desktop)</source>
        <translation>(Nepojmenovaná plocha)</translation>
    </message>
    <message>
        <location filename="../../mouse.cpp" line="57"/>
        <source>Custom actions</source>
        <translation>Uživatelské činnosti</translation>
    </message>
    <message>
        <location filename="../../maindialog.cpp" line="76"/>
        <source>About ObConf-Qt</source>
        <translation>O programu ObConf-Qt</translation>
    </message>
    <message>
        <location filename="../../maindialog.cpp" line="77"/>
        <source>A preferences manager for Openbox

Copyright (c) 2014-2015

Authors:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;

The program is based on ObConf developed by the following developers.
* Dana Jansens &lt;danakj@orodu.net&gt;
* Tim Riley &lt;tr@slackzone.org&gt;
* Javeed Shaikh &lt;syscrash2k@gmail.com&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../archive.cpp" line="26"/>
        <source>&quot;%1&quot; was installed to %1</source>
        <translation>&quot;%1&quot; byl nainstalován do %1</translation>
    </message>
    <message>
        <location filename="../../archive.cpp" line="53"/>
        <source>&quot;%1&quot; was successfully created</source>
        <translation>&quot;%1&quot; byl úspěšně vytvořen</translation>
    </message>
    <message>
        <location filename="../../archive.cpp" line="89"/>
        <source>Unable to create the theme archive &quot;%1&quot;.
The following errors were reported:
%2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../archive.cpp" line="95"/>
        <location filename="../../archive.cpp" line="178"/>
        <source>Unable to run the &quot;tar&quot; command: %1</source>
        <translation>Nelze spustit příkaz &quot;tar&quot;: %1</translation>
    </message>
    <message>
        <location filename="../../archive.cpp" line="115"/>
        <source>Unable to create directory &quot;%1&quot;: %2</source>
        <translation>Nelze vytvořit adresář &quot;%1&quot;: %2</translation>
    </message>
    <message>
        <location filename="../../archive.cpp" line="138"/>
        <source>&quot;%1&quot; does not appear to be a valid Openbox theme directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../archive.cpp" line="148"/>
        <source>Unable to move to directory &quot;%1&quot;: %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../archive.cpp" line="185"/>
        <source>Unable to extract the file &quot;%1&quot;.
Please ensure that &quot;%2&quot; is writable and that the file is a valid Openbox theme archive.
The following errors were reported:
%3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../obconf-qt.cpp" line="53"/>
        <source>ObConf Error</source>
        <translation>Chyba ObConf</translation>
    </message>
    <message>
        <location filename="../../obconf-qt.cpp" line="58"/>
        <source>Copyright (c) 2003-2008   Dana Jansens
Copyright (c) 2003        Tim Riley
Copyright (c) 2007        Javeed Shaikh
Copyright (c) 2013        Hong Jen Yee (PCMan)

This program comes with ABSOLUTELY NO WARRANTY.
This is free software, and you are welcome to redistribute it
under certain conditions. See the file COPYING for details.

</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../obconf-qt.cpp" line="73"/>
        <source>Syntax: obconf [options] [ARCHIVE.obt]

Options:
  --help                Display this help and exit
  --version             Display the version and exit
  --install ARCHIVE.obt Install the given theme archive and select it
  --archive THEME       Create a theme archive from the given theme directory
  --config-file FILE    Specify the path to the config file to use
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../obconf-qt.cpp" line="97"/>
        <source>--install requires an argument
</source>
        <translation>--install vyžaduje argument
</translation>
    </message>
    <message>
        <location filename="../../obconf-qt.cpp" line="103"/>
        <source>--archive requires an argument
</source>
        <translation>--archive vyžaduje argument
</translation>
    </message>
    <message>
        <location filename="../../obconf-qt.cpp" line="109"/>
        <source>--config-file requires an argument
</source>
        <translation>--config-file vyžaduje argument
</translation>
    </message>
    <message>
        <location filename="../../obconf-qt.cpp" line="225"/>
        <location filename="../../obconf-qt.cpp" line="241"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../../obconf-qt.cpp" line="226"/>
        <source>Failed to load an rc.xml. You have probably failed to install Openbox properly.</source>
        <translation>Nepodařilo se nahrát rc.xml. Pravděpodobně se vám nepodařilo nainstalovat ObConf správně.</translation>
    </message>
    <message>
        <location filename="../../obconf-qt.cpp" line="239"/>
        <source>Error while parsing the Openbox configuration file.  Your configuration file is not valid XML.

Message: %1</source>
        <translation>Chyba při zpracování souboru s nastavením pro Openbox. Váš soubor s nastavením není platným souborem XML.</translation>
    </message>
</context>
</TS>
